/*
 * Copyright (c) 2023 New Vector Ltd
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package io.element.android.libraries.designsystem.utils

import androidx.compose.foundation.layout.WindowInsets
import androidx.compose.runtime.Composable
import androidx.compose.ui.platform.LocalDensity
import androidx.compose.ui.platform.LocalLayoutDirection

@Composable
fun WindowInsets.copy(
    top: Int? = null,
    right: Int? = null,
    bottom: Int? = null,
    left: Int? = null
): WindowInsets {
    val density = LocalDensity.current
    val direction = LocalLayoutDirection.current
    return WindowInsets(
        top = top ?: this.getTop(density),
        right = right ?: this.getRight(density, direction),
        bottom = bottom ?: this.getBottom(density),
        left = left ?: this.getLeft(density, direction)
    )
}
